pilot.api.compute.api.State

Package pilot :: Package api :: Package compute :: Module api :: Class State |

# Class State

source code

State.

States used for PilotCompute, PilotData, ComputeUnit, DataUnit and ComputeDataService

Instance Methods
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| Unknown = ``'``Unknown``'``
| New = ``'``New``'``
| Running = ``'``Running``'``
| Done = ``'``Done``'``
| Canceled = ``'``Canceled``'``
| Failed = ``'``Failed``'``
| Pending = ``'``Pending``'``

Properties
Inherited from `object`: `__class__`